@@ -16,7 +16,8 @@ def generate_actions_from_irc_message(args,printer):
     # notification if the message is on a channel I'm monitoring, or play a
     # sound if a message is directly to me.
     global monitored_channels
-    global the_printer = printer
+    global the_printer
+    the_printer = printer
     from_who = args["from_who"]
     channel = args["channel"]
     message = args["message"]
